REST API
========

This section documents the REST API of orlo, which is used to record release information and return information about releases.

.. toctree::


.. autoflask:: orlo:app
   :endpoints:
   :include-empty-docstring:
   :undoc-static:
